@@ -69,9 +69,6 @@
 // KTTS includes.
 #include "talkercode.h"
 #include "filterconf.h"
-#include "selecttalkerdlg.h"
-#include "selectlanguagedlg.h"
-#include "utils.h"
 #include "kttsjobmgr.h"
 
 // Some constants.
